@@ -4,16 +4,16 @@
 
 module Types where
 
-import           Database.Redis
 import           Data.Aeson           as A
 import qualified Data.ByteString      as BS
 import           Data.Text.Encoding
 import qualified Data.Vector          as V
+import           Database.Redis
 import           Prelude              hiding (error)
 
 import           Network.IPv6DB.Types
 
-data Env = Env { redisConn :: Connection }
+newtype Env = Env { redisConn :: Connection }
 
 data RedisResponse
   = RedisOk
@@ -32,7 +32,7 @@ instance ToJSON RedisResponse where
       ]
   toJSON _ = Null
 
-data RedisErrors = RedisErrors [RedisResponse] deriving (Eq, Show)
+newtype RedisErrors = RedisErrors [RedisResponse] deriving (Eq, Show)
 
 instance ToJSON RedisErrors where
   toJSON (RedisErrors rrs) =
